Computes the correlation between observed and imputed values for each observation that has both.
cor.yai (object,vars=NULL,…)an object created by yai or impute.yai.
a list of variables names you want to include, if NULL all available variables are included.
passed to called methods (not currently used)
A data frame with the row names as vars and the column as cor.
The correlations are computed using cor.yai. For data imputation, such
correlations are likely not appropriate (Stage and Crookston 2007).
Stage, A.R.; Crookston, N.L. (2007). Partitioning error components for accuracy-assessment of near neighbor methods of imputation. For. Sci. 53(1):62-72. http://www.fs.fed.us/rm/pubs_other/rmrs_2007_stage_a001.pdf