Provides a generic interface for getting predicted values for yai objects.
# S3 method for yai
predict(object,newdata,…)an object of class yai which is passed as argument to
newtargets, impute.yai, or both of these functions, see details.
a data frame that at a minimum contains the X-variables for new observations.
passed to newtargets and impute.yai, see details.
An object of class impute.yai.
When argument newdata is present function newtargets is called followed by a
call to impute.yai. If include in the …, the arguments k and ann
are passed to newtargets.
When argument newdata is absent, impute.yai is called without first calling
newtargets.
All of the … arguments are passed to impute.yai.
Another form of prediction in imputation is to get the identity of the imputed observations.
Use function foruse for this purpose.