rmsd.yai (object,vars=NULL,scale=FALSE,...)yai or impute.yaiTRUE, the values are scaled (see details), if a named vector,
the values are scaled by the corresponding values.ancillaryData to function impute.yairmsd. When
scale=TRUE, the column name is rmsdS. The scaling factors used, if any,
are returned as an attribute.scale=TRUE, or set of values is supplied, RMSD is divided by the
scaling factor. The scaling factor is the standard deviation of the
reference observations under the assumption that they are representative
of the population.yai, impute.yai and