When method randomforest is used to build a yai
object, the randomForest package computes
several statistics. This function summarizes some of them, including
the variable importance scores computed by function yaiVarImp.
yaiRFsummary(object, nTop=0)an object of class yai.
the nTop most important variables are plotted (returned).
A list containing:
a data frame reporting the error rates and other data from the randomForest(s).
the data frame computed by yaiVarImp.