a list of variables names you want to include, if NULL all available
variables are included.
...
passed to called methods (not currently used)
Value
A data frame with the row names as vars and the column as cor.
Details
The correlations are computed using cor.yai. For data imputation, such
correlations are likely not appropriate; a warning message is issued when
this function is used.